Event

Enum Event 

pub enum Event {
    UserInput {
        thread_id: ThreadId,
        interaction_id: InteractionId,
        payload: Value,
        task_id: Option<TaskId>,
        step_id: Option<StepId>,
        timestamp: DateTime<Utc>,
    },
    AssistantOutput {
        thread_id: ThreadId,
        interaction_id: InteractionId,
        payload: Value,
        task_id: Option<TaskId>,
        step_id: Option<StepId>,
        timestamp: DateTime<Utc>,
    },
    Artifact {
        thread_id: ThreadId,
        interaction_id: InteractionId,
        reference_id: String,
        task_id: Option<TaskId>,
        step_id: Option<StepId>,
        timestamp: DateTime<Utc>,
    },
    ExternalEvent {
        thread_id: ThreadId,
        interaction_id: Option<InteractionId>,
        kind: String,
        payload: Value,
        task_id: Option<TaskId>,
        step_id: Option<StepId>,
        timestamp: DateTime<Utc>,
    },
    SystemTrace {
        thread_id: ThreadId,
        interaction_id: Option<InteractionId>,
        level: String,
        payload: Value,
        task_id: Option<TaskId>,
        step_id: Option<StepId>,
        timestamp: DateTime<Utc>,
    },
}
Event - append-only fact record

Events represent immutable facts that happened in the system.

Variants



UserInput

User input event

Fields

thread_id: ThreadId

Thread this event belongs to

interaction_id: InteractionId

Interaction this event belongs to

payload: Value

Event payload

task_id: Option<TaskId>

Optional owning task ID

step_id: Option<StepId>

Optional owning step ID

timestamp: DateTime<Utc>

Event timestamp



AssistantOutput

Assistant output event

Fields

thread_id: ThreadId

Thread this event belongs to

interaction_id: InteractionId

Interaction this event belongs to

payload: Value

Event payload

task_id: Option<TaskId>

Optional owning task ID

step_id: Option<StepId>

Optional owning step ID

timestamp: DateTime<Utc>

Event timestamp



Artifact

Artifact event (reference to stored artifact)

Fields

thread_id: ThreadId

Thread this event belongs to

interaction_id: InteractionId

Interaction this event belongs to

reference_id: String

Reference ID to the artifact

task_id: Option<TaskId>

Optional owning task ID

step_id: Option<StepId>

Optional owning step ID

timestamp: DateTime<Utc>

Event timestamp



ExternalEvent

External event (webhook, timer, etc.)

Fields

thread_id: ThreadId

Thread this event belongs to

interaction_id: Option<InteractionId>

Optional interaction this event belongs to

kind: String

Kind of external event

payload: Value

Event payload

task_id: Option<TaskId>

Optional owning task ID

step_id: Option<StepId>

Optional owning step ID

timestamp: DateTime<Utc>

Event timestamp



SystemTrace

System trace event (for debugging and auditing)

Fields

thread_id: ThreadId

Thread this event belongs to

interaction_id: Option<InteractionId>

Optional interaction this event belongs to

level: String

Trace level (debug, info, warn, error)

payload: Value

Trace payload

task_id: Option<TaskId>

Optional owning task ID

step_id: Option<StepId>

Optional owning step ID

timestamp: DateTime<Utc>

Event timestamp

Implementations

Source

impl Event

pub fn user_input( thread_id: impl Into<ThreadId>, interaction_id: impl Into<InteractionId>, payload: Value, ) -> Event

Create a new user input event

pub fn assistant_output( thread_id: impl Into<ThreadId>, interaction_id: impl Into<InteractionId>, payload: Value, ) -> Event

Create a new assistant output event

pub fn artifact( thread_id: impl Into<ThreadId>, interaction_id: impl Into<InteractionId>, reference_id: impl Into<String>, ) -> Event

Create a new artifact event

pub fn external( thread_id: impl Into<ThreadId>, kind: impl Into<String>, payload: Value, ) -> Event

Create a new external event

pub fn trace( thread_id: impl Into<ThreadId>, level: impl Into<String>, payload: Value, ) -> Event

Create a new system trace event

pub fn thread_id(&self) -> &str

Get the thread ID of this event

pub fn interaction_id(&self) -> Option<&str>

Get the interaction ID of this event if present.

pub fn task_id(&self) -> Option<&str>

Get the task ID of this event if present.

pub fn step_id(&self) -> Option<&str>

Get the step ID of this event if present.

pub fn timestamp(&self) -> DateTime<Utc>

Get the timestamp of this event

pub fn with_interaction_id( &self, interaction_id: impl Into<InteractionId>, ) -> Event

Return a copy of this event with a new interaction ID.

pub fn with_task_step( &self, task_id: Option<impl Into<TaskId>>, step_id: Option<impl Into<StepId>>, ) -> Event

Return a copy of this event with task and step linkage.