pub enum Event {
UserInput {
thread_id: ThreadId,
interaction_id: InteractionId,
payload: Value,
task_id: Option<TaskId>,
step_id: Option<StepId>,
timestamp: DateTime<Utc>,
},
AssistantOutput {
thread_id: ThreadId,
interaction_id: InteractionId,
payload: Value,
task_id: Option<TaskId>,
step_id: Option<StepId>,
timestamp: DateTime<Utc>,
},
Artifact {
thread_id: ThreadId,
interaction_id: InteractionId,
reference_id: String,
task_id: Option<TaskId>,
step_id: Option<StepId>,
timestamp: DateTime<Utc>,
},
ExternalEvent {
thread_id: ThreadId,
interaction_id: Option<InteractionId>,
kind: String,
payload: Value,
task_id: Option<TaskId>,
step_id: Option<StepId>,
timestamp: DateTime<Utc>,
},
SystemTrace {
thread_id: ThreadId,
interaction_id: Option<InteractionId>,
level: String,
payload: Value,
task_id: Option<TaskId>,
step_id: Option<StepId>,
timestamp: DateTime<Utc>,
},
}Expand description
Event - append-only fact record
Events represent immutable facts that happened in the system.
Variants
UserInput
User input event
Fields

interaction_id: InteractionIdInteraction this event belongs to
AssistantOutput
Assistant output event
Fields

interaction_id: InteractionIdInteraction this event belongs to
Artifact
Artifact event (reference to stored artifact)
Fields

interaction_id: InteractionIdInteraction this event belongs to
ExternalEvent
External event (webhook, timer, etc.)
Fields

interaction_id: Option<InteractionId>Optional interaction this event belongs to
SystemTrace
System trace event (for debugging and auditing)
Fields

interaction_id: Option<InteractionId>Optional interaction this event belongs to
Implementations
Sourceimpl Event
impl Event
Sourcepub fn user_input(
thread_id: impl Into<ThreadId>,
interaction_id: impl Into<InteractionId>,
payload: Value,
) -> Event
pub fn user_input( thread_id: impl Into<ThreadId>, interaction_id: impl Into<InteractionId>, payload: Value, ) -> Event
Create a new user input event
Sourcepub fn assistant_output(
thread_id: impl Into<ThreadId>,
interaction_id: impl Into<InteractionId>,
payload: Value,
) -> Event
pub fn assistant_output( thread_id: impl Into<ThreadId>, interaction_id: impl Into<InteractionId>, payload: Value, ) -> Event
Create a new assistant output event
Sourcepub fn artifact(
thread_id: impl Into<ThreadId>,
interaction_id: impl Into<InteractionId>,
reference_id: impl Into<String>,
) -> Event
pub fn artifact( thread_id: impl Into<ThreadId>, interaction_id: impl Into<InteractionId>, reference_id: impl Into<String>, ) -> Event
Create a new artifact event
Sourcepub fn external(
thread_id: impl Into<ThreadId>,
kind: impl Into<String>,
payload: Value,
) -> Event
pub fn external( thread_id: impl Into<ThreadId>, kind: impl Into<String>, payload: Value, ) -> Event
Create a new external event
Sourcepub fn trace(
thread_id: impl Into<ThreadId>,
level: impl Into<String>,
payload: Value,
) -> Event
pub fn trace( thread_id: impl Into<ThreadId>, level: impl Into<String>, payload: Value, ) -> Event
Create a new system trace event
Sourcepub fn interaction_id(&self) -> Option<&str>
pub fn interaction_id(&self) -> Option<&str>
Get the interaction ID of this event if present.
Sourcepub fn with_interaction_id(
&self,
interaction_id: impl Into<InteractionId>,
) -> Event
pub fn with_interaction_id( &self, interaction_id: impl Into<InteractionId>, ) -> Event
Return a copy of this event with a new interaction ID.